@@ -14,13 +14,12 @@
 
 from __future__ import annotations
 
-from pprint import pprint
-
 import firefly as ff
+
 import firefly_business_rules.domain as domain
 
 
-@ff.rest('/evaluate-rules', method='POST')
+@ff.command_handler()
 class EvaluateRules(ff.ApplicationService):
     _registry: ff.Registry = None
     _engine: domain.RulesEngine = None
